list_funs: Create Sorted List of Function Names

Description Usage Arguments Value Examples

View source: R/list.R

Description

Any functions appearing in the input text are identified and their names.
Names are then sorted alphabetically and outputted as a commented text in a "function per line" fashion.

Usage

1

Arguments

text

String

Value

commented list of function names

Examples

1
2
3
4
5
cat(
  list_funs(
    'hi <- function() { "hi world" }
    hello <- function() { "hello world" }
    howdy <- function() { "howdy workld" }'))

ShaulAb/alphabetter documentation built on Oct. 13, 2019, 7:33 a.m.